# Changelog

## 0.5.2 2024 Oct 18

- implement #4: support for 'as-is' tags, i.e. the ones starting with a dash

## 0.5.1 2023 Dec 2

- no actual change, manual tests done for apply_on_cells
  automated tests in the works but not yet working

## 0.5.0 2023 Dec 1

- fix #1: use correct NotebookPanel instance

## 0.4.4 2023 Nov 26

- export md_toggle_multi
- re-release after several crippled attempts

## 0.3.1 2023 Jul 2

- initial release
- requires jlab4
